# Spec file license: MIT

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

Name:           euca2ools
Version:        2.1.4
Release:        1%{?dist}
Summary:        Eucalyptus/AWS-compatible command line tools

Group:          Applications/Internet
License:        BSD
URL:            http://www.eucalyptus.com/
Source0:        http://downloads.eucalyptus.com/software/euca2ools/2.0/source/euca2ools-%{version}.tar.gz

Requires:       m2crypto
# This requires EC2Connection.register_image to have a virtualization_type arg.
# The 2.13.3-1 package includes it as a backport.
Requires:       python-boto >= 2.13.3-1
Requires:       rsync
Requires:       util-linux

Obsoletes:      euca2ools-eustore < 2.1.1-2
Provides:       euca2ools-eustore = %{version}-%{release}

BuildRequires:  help2man
BuildRequires:  python-devel
BuildRequires:  python-setuptools-devel

# For building man pages
BuildRequires:  python-boto >= 2.0
BuildRequires:  m2crypto

BuildArch:      noarch

# Disable SSL cert validation by default for boto 2.6+ compatibility
# (Eucalyptus uses self-signed certs by default, which breaks connections)
Patch1:         euca2ools-2.1.3-boto-ssl.patch
# Add euca-register --virtualization-type per Fedora rel-eng's request
# Requires fixes from boto 2.14, backported in python-boto-2.13.3-1
Patch2:         euca2ools-2.1.4-virttype.patch


%description
Euca2ools are command line tools used to interact with Eucalyptus,
a service overlay designed to be interface-compatible with Amazon Web
Services (AWS), as well as AWS itself.


%prep
%setup -q
%patch1 -p1
%patch2 -p1


%build
%{__python} setup.py build
export PYTHON=%{__python}
sh -xe generate-manpages.sh


%install
%{__python} setup.py install --skip-build --root %{buildroot}
%{__python} setup.py install -O1 --skip-build --root %{buildroot}

export DESTDIR=%{buildroot}
export PREFIX=%{_prefix}
sh -xe install-manpages.sh


%clean
rm -rf %{buildroot}


%files
%{_bindir}/euare-*
%{_bindir}/euca-*
%{_bindir}/eustore-*
%{_mandir}/man1/euare*
%{_mandir}/man1/euca*
%{_mandir}/man1/eustore*
%{python_sitelib}/%{name}-*.egg-info
%{python_sitelib}/%{name}/
%doc CHANGELOG
%doc COPYING
%doc INSTALL
%doc README


%changelog
* Thu Sep 26 2013 Garrett Holmstrom <gholms@fedoraproject.org> - 2.1.4-1
- Upstream update (2.1.4)
- Fixed eustore-install-image breakage from 2.1.3-2 [RH:1001433]

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 21 2013 Garrett Holmstrom <gholms@fedoraproject.org> - 2.1.3-2
- Disabled SSL cert validation to make things work with boto 2.6+
- Fixed eustore account name checking [TOOLS-282]
- Fixed eustore registering images with the wrong type [TOOLS-184]
- Fixed euare-userlistpolicies -v --delegate [TOOLS-281]
- Fixed euca-get-console-output crash on no output
- Added euca-register --virtualization type (note that it requires special privs)

* Mon Mar  4 2013 Garrett Holmstrom <gholms@fedoraproject.org> - 2.1.3-1
- Upstream update (2.1.3) [RH:916716]
- Fix euare-useraddpolicy --delegate

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Oct 10 2012 Garrett Holmstrom <gholms@fedoraproject.org> - 2.1.1-2
- Combined the -eustore package into the main package [RH:865108]

* Wed Sep 13 2012 Garrett Holmstrom <gholms@fedoraproject.org> - 2.1.1-1
- Upstream update (2.1.1)
- The new EuStore tools introduced in this version are in the -eustore package.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Apr 17 2012 Garrett Holmstrom <gholms@fedoraproject.org> - 2.0.2-1
- Upstream update (2.0.2)

* Tue Apr 17 2012 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.2-1
- Upstream update (1.3.2)

* Wed Apr  4 2012 Garrett Holmstrom <gholms@fedoraproject.org> - 2.0.1-1
- Upstream update (2.0.1)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jul 22 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-12
- Fixed registration of EBS-backed images

* Fri Jul  1 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-11
- Backported support for bundle upload location constraints [LP:704658]

* Fri Jun 10 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-11
- Fixed handling of empty block device sizes
- Fixed euca-describe-image-attribute -B output [LP:795395]

* Tue Apr 26 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-10
- Added unlisted dependencies for euca-bundle-vol
- Fixed typos introduced by the FSID patch
- Fixed bundling failure on small images [LP:760157]
- Fixed use of bad mkfs options on older systems [LP:771498]

* Tue Mar 22 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-9
- Work around Boto 2.0 + Eucalyptus 2.0 incompatibility [RH:684976]

* Mon Mar  7 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-8
- Fix Boto 2.0 compatibility

* Fri Mar  4 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-7
- Fix backtrace when --user-data-file does not exist [LP:726901]
- Don't require source subnet when (de)authorizing [LP:725170]

* Thu Feb 17 2011 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-6
- Stop stripping leading '0's from user IDs [LP:479823]
- Fix bad behavior with user IDs that contain '-'
- Preserve filesystem labels and UUIDs when bundling [LP:667793 LP:672986]

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 15 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-4
- Fix EC2-incompatible bundle checksumming [LP:665667]

* Wed Dec  8 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-3
- Fix URI parsing in main euca2ools module [RH:658560 LP:405628]
- Fix euca-confirm-product-instance crash [LP:548483]

* Wed Dec  8 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-2.1
- Remove extraneous copies of executables from %%{_bindir}

* Thu Nov 18 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-2
- Fix euca-bundle-image returning Odd-length string errors [LP:509562]
- Fix euca-bundle-image failure to use symbolic links [LP:522292]
- Fix euca-bundle-image --help yielding 'Invalid user' messages [LP:546526]
- Fix rebundled instance boot failure [LP:551847]
- Check a default location for Eucalyptus certificate [LP:479836]
- Fix euca-describe-image-attribute --kernel or --ramdisk [LP:546551]
- Fix euca-describe-images listing too many images on EC2 [LP:541468]
- Fix euca-download-bundle usage message [LP:546567]
- Fix failures related to a spurious space in euca-describe-images [LP:531453]
- Fix euca-run-instances parameter validation [LP:546420]
- Fix euca-run-instances usage message [LP:530816]

* Sat Sep  4 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3.1-1
- Upstream bugfix release [LP:629118]

* Wed Aug 25 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.3-1
- Update to 1.3 final
- This release no longer requires python-boto 2.0

* Fri Jul 30 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.2-5.20100701bzr293
- Rebuild prerelease against Python 2.7

* Thu Jul 22 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.2-4.20100701bzr293
- Update to a snapshot that includes support for block device mapping [575258]

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Mar 22 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.2-2
- Fix bad version reporting [LP:522396]
- Fix broken rc file searching [LP:516738 LP:524652]
- Fix reversed kernel+ramdisk display order in euca-describe-images [LP:256697]
- Fix broken file patch processing [LP:522060]
- Make euca-create-volume documentation consistent [LP:542097]
- Correct help files for euca-{modify,reset}-image-attribute [LP:543559]
- Fix euca-bundle-image --block-device-mapping [575166]

* Thu Feb 18 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.2-1
- Upstream update

* Thu Feb  4 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.1-5
- Fix changelog

* Wed Jan 20 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.1-4
- Stop requiring swig
- Take ownership of %%{python_sitelib}/%%{name} directory
- Clarify description
- Drop now-superfluous buildroot tag and cleaning step

* Fri Jan 15 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.1-3
- Update download URI

* Fri Jan  8 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.1-2
- Add COPYING and INSTALL docfiles

* Fri Jan  8 2010 Garrett Holmstrom <gholms@fedoraproject.org> - 1.1-1
- Initial packaging attempt
